#
# spec file for package traefik
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define project github.com/traefik/traefik

Name:           traefik
Version:        2.10.1
Release:        1.1
Summary:        The Cloud Native Application Proxy
License:        MIT
Group:          Productivity/Networking/Web/Proxy
URL:            https://traefik.io/
Source0:        %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
Source2:        traefik.service
Source3:        traefik.toml
Source4:        %{name}-%{version}.webui.tar.gz
BuildRequires:  go-bindata
BuildRequires:  golang-packaging
BuildRequires:  systemd-rpm-macros
BuildRequires:  (golang(API) >= 1.20 with golang(API) < 1.21)
Recommends:     podman
%{?systemd_requires}
%{go_provides}
# Make sure that the binary is not getting stripped.
%{go_nostrip}

%description
Traefik (pronounced traffic) is a modern HTTP reverse proxy and load balancer
that makes deploying microservices easy. Traefik integrates with your existing
infrastructure components (Docker, Swarm mode, Kubernetes, Marathon, Consul,
Etcd, Rancher, Amazon ECS) and configures itself automatically and dynamically.

Pointing Traefik at your orchestrator should be the only configuration step you need.

%prep
%setup -q

%build
build_date=$(date -u -d @${SOURCE_DATE_EPOCH:-$(date +%%s)} +"%%Y%%m%%d")
%{goprep} %{project}

# tarball causes "inconsistent vendoring"
tar -xf %{SOURCE1}

# unpack webui
tar -xf %{SOURCE4}

# see script/generate
go generate

# see script/binary
CGO_ENABLED=0 GOGC=off go build \
  -buildmode=pie \
  -mod=vendor \
  -ldflags "-s -w \
  -X github.com/traefik/traefik/v2/pkg/version.Version=%{version} \
  -X github.com/traefik/traefik/v2/pkg/version.Codename='' \
  -X github.com/traefik/traefik/v2/pkg/version.BuildDate=${build_date}" \
  -installsuffix nocgo \
  -o traefik ./cmd/traefik

%install
install -d %{buildroot}/%{_sbindir}
install -D -p -m 0755 %{name} %{buildroot}%{_bindir}/%{name}

# service
install -D -p -m 0644 %{SOURCE2} %{buildroot}%{_unitdir}/%{name}.service
ln -sf %{_sbindir}/service %{buildroot}%{_sbindir}/rc%{name}

# configuration
install -D -p -m 0644 %{SOURCE3} %{buildroot}%{_sysconfdir}/%{name}/%{name}.toml

%pre
%service_add_pre %{name}.service

%post
%service_add_post %{name}.service
%{fillup_only -n %{name}}

%preun
%service_del_preun %{name}.service

%postun
%service_del_postun %{name}.service

%files
%license LICENSE.md
%doc README.md SECURITY.md CONTRIBUTING.md
%{_bindir}/%{name}

%{_unitdir}/%{name}.service
%{_sbindir}/rc%{name}

%dir %{_sysconfdir}/%{name}
%config(noreplace) %{_sysconfdir}/%{name}/%{name}.toml

%changelog
* Mon Jun 12 2023 alexandre.vicenzi@suse.com
- Update to version 2.10.1:
  * CVEs
  * CVE-2022-41724 (bsc#1208271)
  * CVE-2023-24534 (bsc#1210127)
  * CVE-2023-29013 (bsc#1210505)
  * Enhancements
  * [docker] Expose ContainerName in Docker provider
  * [hub] Remove hub configuration out of experimental
  * [k8s/crd] Introduce traefik.io API Group CRDs
  * [k8s/ingress,k8s/crd,k8s] Native Kubernetes service load-balancing
  * [middleware,metrics] Add prometheus metric requests_total with headers
  * [nomad] Support multiple namespaces in the Nomad Provider
  * [tracing] Add support to send DataDog traces via Unix Socket
  * [webui] Display period setting of the RateLimit middleware in the webui
  * [webui] Modify the Hub Button
  * Bug fixes
  * [docker] Expose ContainerName in Docker provider
  * [docker] Only warn about missing docker network when network_mode is not host or container
  * [ecs] Prevent panicking when a container has no network interfaces
  * [file] Make file provider more resilient wrt first configuration
  * [hub] hub: get out of experimental.
  * [k8s/crd] Introduce traefik.io API Group CRDs
  * [k8s/ingress,k8s/crd,k8s] Native Kubernetes service load-balancing
  * [logs] Differentiate UDP stream and TCP connection in logs
  * [metrics] Include user-defined default cert for traefik_tls_certs_not_after metric
  * [middleware,metrics] Add prometheus metric requests_total with headers
  * [middleware] Prevent from no rate limiting when average is zero
  * [middleware] Prevents superfluous WriteHeader call in the error middleware
  * [middleware] Sanitize X-Forwarded-Proto header in RedirectScheme middleware
  * [nomad] Fix default configuration settings for Nomad Provider
  * [nomad] Fix Nomad client TLS defaults
  * [nomad] Support multiple namespaces in the Nomad Provider
  * [plugins] Improve DeepCopy of PluginConf
  * [server] Remove User-Agent header removal from ReverseProxy director func
  * [tls,tcp] Adds the support for IPv6 in the TCP HostSNI matcher
  * [tracing] Add support to send DataDog traces via Unix Socket
  * [server] Update golang.org/x/net to v0.7.0 (CVE-2022-41724)
- Update Go version (CVE-2023-24534, CVE-2023-29013)
* Tue Jan 17 2023 alexandre.vicenzi@suse.com
- Update to version 2.9.6:
  * CVEs
  * CVE-2022-23469
  * CVE-2022-46153
  * CVE-2022-41717
  * Bug fixes
  * [acme] Update go-acme/lego to v4.9.1
  * [k8s/crd] Support of allowEmptyServices in TraefikService
  * [logs] Remove logs of the request
  * [plugins] Increase the timeout on plugin download
  * [server] Update golang.org/x/net (CVE-2022-41717, bsc#1207208)
  * [tls] Handle broken TLS conf better
  * [tracing] Update DataDog tracing dependency to v1.43.1
  * [webui] Add missing serialNumber passTLSClientCert option to middleware panel
* Mon Nov 28 2022 alexandre.vicenzi@suse.com
- Update to version 2.9.5:
  * Enhancements
  * [acme,tls] ACME Default Certificate
  * [consul,etcd,zk,kv,redis] Update valkeyrie to v1.0.0
  * [consulcatalog,nomad] Support Nomad canary deployment
  * [consulcatalog] Move consulcatalog provider to only use health apis
  * [docker] Add support for reaching containers using host networking on Podman
  * [docker] Use IPv6 address
  * [docker] Add allowEmptyServices for Docker provider
  * [ecs] Add support for ECS Anywhere
  * [healthcheck] Add a method option to the service Health Check
  * [http3] Upgrade quic-go to v0.28.0
  * [http] Start polling HTTP provider at the beginning
  * [k8s/crd,plugins] Load plugin configuration field value from Kubernetes Secret
  * [logs,tcp] Quiet down TCP RST packet error on read operation
  * [metrics] Add traffic size metrics
  * [middleware,pilot] Remove Pilot support
  * [rules,tcp] Support ALPN for TCP + TLS routers
  * [tcp,service,udp] Make the loadbalancers servers order random
  * [tls] Change default TLS options for more security
  * [tracing] Add Datadog GlobalTags support
  * Bug fixes
  * [logs,middleware] Create a new capture instance for each incoming request
  * [acme] Update go-acme/lego to v4.9.0
  * [kv,redis] Fix Redis configuration type
  * [logs,middleware,metrics] Handle capture on redefined http.responseWriters
  * [middleware,k8s] Remove raw cert escape in PassTLSClientCert middleware
  * [plugins] Update Yaegi to v0.14.3
  * Remove side effect on default transport tests
  * [acme] Fix ACME panic
  * [server] Update golang.org/x/net to latest version
  * [consulcatalog] Fix UDP loadbalancer tags not being used with Consul Catalog
  * [docker,rancher,ecs,provider] Simplify AddServer algorithm
  * [plugins] Allow empty plugin configuration
  * [rules] Fix query parameter matching with equal
  * [server] Optimize websocket headers handling
  * [plugins] Update Yaegi to v0.14.2
  * [server] Fix IPv6 addr with square brackets
  * [webui,api] Display default TLS options in the dashboard
* Wed Sep  7 2022 alexandre.vicenzi@suse.com
- Update to version 2.8.4:
  * Enhancements
  * [consul,consulcatalog] Support multiple namespaces for Consul and ConsulCatalog providers
  * [logs] Add destination address to debug log
  * [middleware,provider,tls] Deprecate caOptional option in client TLS configuration
  * [middleware] Support URL replacement in errors middleware
  * [middleware] Allow config of additional CircuitBreaker params
  * [provider] Implement Traefik provider for Nomad orchestrator
  * [server] Allow HTTP/2 max concurrent stream configuration
  * [tls,k8s/crd] Support certificates configuration in TLSStore CRD
  * [webui,pilot,hub] Add Traefik Hub button and deprecate Pilot
  * [webui,plugins] Reach the catalog of plugins from the Traefik dashboard
  * Bug fixes
  * [docker,docker/swarm] Fix Docker provider mem leak on operation retries
  * [middleware] Fix retry middleware on panic
  * [plugins] Allow Traefik starting even if plugin service is unavailable
  * [marathon] Add missing context in backoff for Marathon
  * [k8s/ingress,k8s] Place namespace before name in router key for Ingress
  * [logs,middleware,tracing] Remove request dump from IPWhitelist debug log and tracing message
  * [metrics] Control allocation and copy of labelNamesValues type
  * [metrics] Fix service up gauge for Prometheus metrics
  * [yaml] Add missing inline tag for YAML serialization
  * [middleware,metrics] Improve performances when Prometheus metrics are enabled
  * [middleware] Support forwarded websocket protocol in RedirectScheme
  * [nomad] Use configured token in the Nomad client
  * [metrics] Ensure Datadog client is cleanly stopped
  * [healthcheck,service] Do not make multiple requests to the same URL for balancer healthcheck
  * [healthcheck,service] Add log when missing path in health check
  * [k8s/gatewayapi] Allow multiple listeners on same port in Gateway API provider
  * [middleware] RedirectScheme redirects based on X-Forwarded-Proto header
  * [rules] Fix HostRegexp and Query muxers
  * [logs] Fix invalid placeholder in log message
* Tue Jun  7 2022 alexandre.vicenzi@suse.com
- Update to version 2.7.0:
  * Enhancements
  * [consulcatalog] Watch for Consul events to rebuild the dynamic configuration
  * [healthcheck] Add Failover service
  * [http3] Configure advertised port using h3 server option
  * [hub] Add Traefik Hub Integration
  * [k8s/crd,k8s] Allow empty services in Kubernetes CRD
  * [metrics] Support InfluxDB v2 metrics backend
  * [plugins] Remove Pilot token setup constraint to use plugins
  * [provider] Refactor configuration reload/throttling
  * [rules,tcp] Add HostSNIRegexp rule matcher for TCP
  * [tcp] Add muxer for TCP Routers
  * [webui,pilot] Add Traefik Hub access and remove Pilot access
  * [webui] Add a link to service on router detail view
  * Bug fixes
  * [hub] Skip Provide when TLS is nil
  * [tcp] Fix TCP-TLS/HTTPS routing precedence
  * [webui,hub] Use dedicated entrypoint for the tunnels
  * [logs,k8s/crd] Fix log statement for ExternalName misconfig
  * [tcp,service] Fix initial tcp lookup when address is not available
  * [tls] Fix panic when getting certificates with non-existing store
  * [acme] Fix RenewInterval computation in ACME provider
  * [ecs,logs] Remove duplicate error logs
  * [ecs] Filter out ECS anywhere instance IDs
  * [middleware] Re-add missing writeheader call in flush
  * [middleware] Fix bug for when custom page is large enough
  * [middleware] Fix regexp handling in redirect middleware
  * [plugins] Fix slice parsing for plugins
  * [tls] Return TLS unrecognized_name error when no certificate is available
  * [acme] Add domain to HTTP challenge errors
  * [metrics] Fix metrics bucket key high cardinality
  * [middleware,tls] Use CNAME for SNI check on host header
  * [middleware,tracing] Rename Datadog span tags
  * [tls] Apply the same approach as the rules system on the TLS configuration choice
* Fri Feb  4 2022 alexandre.vicenzi@suse.com
- Update to version 2.6.0:
  * Updated Kubernetes Gateway API provider
  * Consul Enterprise support
  * Consul Connect support
  * Inflight request middleware for TCP routers
  * HTTP/3 support (experimental)
  * Added support for loading plugins directly from the filesystem (Local Plugins)
  * Added ability to create Provider Plugins
  * Added TCP Middleware
  * Kubernetes 1.22 API changes
  * Dropped support for Ingress API versions extensions/v1beta1
  * Updated Traefik Proxy CRDs to use API apiextensions.k8s.io/v1
* Wed Jul 28 2021 alexandre.vicenzi@suse.com
- Update to version 2.4.12:
  * Get Kubernetes server version early
  * Don't remove ingress config on API call failure
  * Ratelimiter: use correct ttlSeconds value, and always call Set
  * Check if defaultcertificate is defined in store
  * Disable ExternalName Services by default on Kubernetes providers
  * Fix: malformed Kubernetes resource names and references in tests
  * Disable Cross-Namespace by default for IngressRoute provider
  * Accesslog: support multiple values for a given header
  * Ignore http 1.0 request host missing errors
  * Headers Middleware: support http.CloseNotifier interface
  * Detect certificates content modifications
  * Update go-acme/lego to v4.4.0
  * Fix: ACME preferred chain.
  * Remove error when HTTProutes is empty
  * Fix incorrect behaviour with multi-port endpoint subsets
  * Kubernetes ingress provider to search via all endpoints
  * Fix plugin unzip call on windows
  * Update Yaegi to v0.9.17
  * Bump paerser to v0.1.4
  * Create buffered signals channel
  * Fix: use defaultEntryPoints when no entryPoint is defined in a TCPRouter
  * Use a dynamic buffer to handle client Hello SNI detection
  * Error span on 5xx only
* Wed May 19 2021 Bernhard Wiedemann <bwiedemann@suse.com>
- Allow to override build date with SOURCE_DATE_EPOCH
  in order to make builds reproducible (boo#1047218)
* Thu Apr 29 2021 alexandre.vicenzi@suse.com
- Update to version 2.4.8:
  * Prepare release v2.4.8
  * Raise errors for non-ASCII domain names in a router's rules
  * Adding an option to (de)activate Pilot integration into the Traefik dashboard
  * Doc: improve basic auth middleware httpasswd example
  * Add missing `traefik.` prefix across sample config
  * Fix travis docker image pulling for docs
  * updating docs to remove a no longer needed note
  * Update to gateway-api v0.2.0
  * server: updating go-proxyproto with security bugfix from upstream
  * Update go-acme/lego to v4.3.1
* Thu Jan 10 2019 pgeorgiadis@suse.com
- Initial package release to version 1.7.7:
  * Check for watched namespace before getting kubernetes objects
  * Allow empty path with App-root annotation
  * kubernetes: sort and uniq TLS secrets
  * Skip TLS section with no secret in Kubernetes ingress
